import { Menu, Transition } from "@headlessui/react";
import React, { Fragment } from "react";
import classNames from "classnames";
import { Disclosure } from "@headlessui/react";

/* -------------------------------------------------------------------------- */
/*                                 Components                                 */
/* -------------------------------------------------------------------------- */
import ContextMenuAction from "./drop-down-menu/ContextMenuAction";
import ContextMenu from "./drop-down-menu/ContextMenu";
import { Button } from "./Button/Button";
import Link from "./typography/Link";

/* -------------------------------------------------------------------------- */
/*                                    Icons                                   */
/* -------------------------------------------------------------------------- */
import { ReactComponent as SVGFavoriteOutlined } from "assets/svg/favorite-outlined.svg";
import { ReactComponent as SVGHamburger } from "assets/svg/hamburger.svg";
import { ReactComponent as SVGFolder } from "assets/svg/folder.svg";
import { ReactComponent as SVGFile } from "assets/svg/file.svg";
import { ReactComponent as SVGEye } from "assets/svg/eye.svg";
import { ReactComponent as SVGArrowUp } from "assets/svg/arrow-up.svg";
import { ReactComponent as SVGCaretDown } from "assets/svg/caret-down.svg";
import { useTranslation } from "react-i18next";

type Props = React.ComponentPropsWithoutRef<"div">;

const Burger = (props: Props) => {
  const { t, i18n } = useTranslation();
  return (
    <div {...props}>
      <Menu as="div" className="relative inline-block text-left z-30">
        <div>
          <Menu.Button as={Button} emphasis="low">
            <Button.Icon>
              <SVGHamburger className="h-6 w-6" />
            </Button.Icon>
          </Menu.Button>
        </div>

        <Transition
          as={Fragment}
          enter="transition ease-out duration-100"
          enterFrom="transform opacity-0 scale-95"
          enterTo="transform opacity-100 scale-100"
          leave="transition ease-in duration-75"
          leaveFrom="transform opacity-100 scale-100"
          leaveTo="transform opacity-0 scale-95"
        >
          <Menu.Items
            className="origin-top-right absolute right-0 mt-5 w-48 rounded-md 
          shadow-lg bg-white ring-1 ring-black ring-opacity-5 focus:outline-none"
          >
            <div className="py-1">
              <Disclosure>
                <Disclosure.Button className="uppercase text-base	 px-2 py-1">
                  <Link className="text-[#096DD9]">
                    {t("navbar.createNew")}
                  </Link>
                </Disclosure.Button>
              </Disclosure>
              <hr />
              <Disclosure>
                {({ open }) => (
                  <>
                    <Disclosure.Button
                      className="uppercase px-2 flex justify-between w-full items-center
                      py-1
                      hover:bg-gray-100
                      text-base	
                     "
                    >
                      <span>{t("navbar.library.navTitle")}</span>
                      <SVGArrowUp
                        className={`${
                          open ? "rotate-180 transform" : "rotate-360"
                        } h-5 w-5 `}
                      />
                    </Disclosure.Button>

                    <Link to="#" className="w-full">
                      <Disclosure.Panel
                        className="px-2 flex items-center font-normal	gap-1 py-1 w-full ease-in-out duration-300
                        rounded
                        hover:bg-gray-200
                        text-base	
                        "
                      >
                        <SVGFile className="stroke-black w-4 h-4" />
                        <span>{t("navbar.library.publications")}</span>
                      </Disclosure.Panel>
                    </Link>

                    <Link to="#" className="w-full">
                      <Disclosure.Panel
                        className="px-2 flex items-center font-normal	gap-1 py-1 w-full ease-in-out duration-300
                        rounded
                        hover:bg-gray-200
                        text-base	
                        "
                      >
                        <SVGFavoriteOutlined className="stroke-black w-4 h-4" />
                        <span>{t("navbar.library.favorites")}</span>
                      </Disclosure.Panel>
                    </Link>

                    <Link to="#" className="w-full">
                      <Disclosure.Panel
                        className="px-2 flex items-center font-normal	gap-1 py-1 w-full ease-in-out duration-300
                        rounded
                        hover:bg-gray-200
                        text-base	
                        "
                      >
                        <SVGFolder className="stroke-black fill-black w-4 h-4" />
                        <span>{t("navbar.library.collections")}</span>
                      </Disclosure.Panel>
                    </Link>

                    <Link to="#" className="w-full">
                      <Disclosure.Panel
                        className="px-2 flex items-center font-normal	gap-1 py-1 w-full ease-in-out duration-300
                         rounded
                         hover:bg-gray-200
                         text-base	
                         "
                      >
                        <SVGEye className="stroke-black w-4 h-4" />
                        <span>{t("navbar.library.recentViewed")}</span>
                      </Disclosure.Panel>
                    </Link>
                  </>
                )}
              </Disclosure>
              <hr />
              {/* Third list - start */}
              <Disclosure>
                {({ open }) => (
                  <>
                    <Disclosure.Button
                      className="uppercase px-2 flex justify-between w-full items-center
                      py-1
                      hover:bg-gray-100
                      text-base	
                     "
                    >
                      <span>{t("navbar.about.navTitle")}</span>
                      <SVGArrowUp
                        className={`${
                          open ? "rotate-180 transform" : "rotate-360"
                        } h-5 w-5 `}
                      />
                    </Disclosure.Button>

                    <Link to="#" className="w-full">
                      <Disclosure.Panel
                        className="px-2 flex items-center font-normal	gap-1 py-1 w-full ease-in-out duration-300
                        rounded
                        hover:bg-gray-200
                        text-base	
                        "
                      >
                        <span>{t("navbar.about.aboutProject")}</span>
                      </Disclosure.Panel>
                    </Link>

                    <Link to="#" className="w-full">
                      <Disclosure.Panel
                        className="px-2 flex items-center font-normal	gap-1 py-1 w-full ease-in-out duration-300
                        rounded
                        hover:bg-gray-200
                        text-base	
                        "
                      >
                        <span>{t("navbar.about.contacts")}</span>
                      </Disclosure.Panel>
                    </Link>

                    <Link to="#" className="w-full">
                      <Disclosure.Panel
                        className="px-2 flex items-center font-normal	gap-1 py-1 w-full ease-in-out duration-300
                        rounded
                        hover:bg-gray-200
                        text-base	
                        "
                      >
                        <span>{t("navbar.about.help")}</span>
                      </Disclosure.Panel>
                    </Link>
                  </>
                )}
              </Disclosure>
              {/* Third list - end */}
            </div>
          </Menu.Items>
        </Transition>
      </Menu>
    </div>
  );
};

export default Burger;
